@@ -548,11 +548,15 @@ static bool skel_lock(vfs_handle_struct *handle, files_struct *fsp, int op,
 	return SMB_VFS_NEXT_LOCK(handle, fsp, op, offset, count, type);
 }
 
-static int skel_kernel_flock(struct vfs_handle_struct *handle,
-			     struct files_struct *fsp, uint32_t share_mode,
-			     uint32_t access_mask)
+static int skel_filesystem_sharemode(struct vfs_handle_struct *handle,
+				     struct files_struct *fsp,
+				     uint32_t share_mode,
+				     uint32_t access_mask)
 {
-	return SMB_VFS_NEXT_KERNEL_FLOCK(handle, fsp, share_mode, access_mask);
+	return SMB_VFS_NEXT_FILESYSTEM_SHAREMODE(handle,
+						 fsp,
+						 share_mode,
+						 access_mask);
 }
 
 static int skel_fcntl(struct vfs_handle_struct *handle,
@@ -663,6 +667,8 @@ static uint64_t skel_fs_file_id(vfs_handle_struct *handle,
 
 struct skel_offload_read_state {
 	struct vfs_handle_struct *handle;
+	uint32_t flags;
+	uint64_t xferlen;
 	DATA_BLOB token;
 };
 
@@ -710,6 +716,8 @@ static void skel_offload_read_done(struct tevent_req *subreq)
 	status = SMB_VFS_NEXT_OFFLOAD_READ_RECV(subreq,
 						state->handle,
 						state,
+						&state->flags,
+						&state->xferlen,
 						&state->token);
 	TALLOC_FREE(subreq);
 	if (tevent_req_nterror(req, status)) {
@@ -723,6 +731,8 @@ static void skel_offload_read_done(struct tevent_req *subreq)
 static NTSTATUS skel_offload_read_recv(struct tevent_req *req,
 				       struct vfs_handle_struct *handle,
 				       TALLOC_CTX *mem_ctx,
+				       uint32_t *flags,
+				       uint64_t *xferlen,
 				       DATA_BLOB *_token)
 {
 	struct skel_offload_read_state *state = tevent_req_data(
@@ -745,6 +755,8 @@ static NTSTATUS skel_offload_read_recv(struct tevent_req *req,
 		return NT_STATUS_NO_MEMORY;
 	}
 
+	*flags = state->flags;
+	*xferlen = state->xferlen;
 	*_token = token;
 	return NT_STATUS_OK;
 }
@@ -1315,7 +1327,7 @@ static struct vfs_fn_pointers skel_transparent_fns = {
 	.ftruncate_fn = skel_ftruncate,
 	.fallocate_fn = skel_fallocate,
 	.lock_fn = skel_lock,
-	.kernel_flock_fn = skel_kernel_flock,
+	.filesystem_sharemode_fn = skel_filesystem_sharemode,
 	.fcntl_fn = skel_fcntl,
 	.linux_setlease_fn = skel_linux_setlease,
 	.getlock_fn = skel_getlock,
